# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RehydrationInstructionsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lookup': 'list[RehydrationSeriesLookupOutputV1]',
        'map_marker': 'MapMarkerRehydrationInstructionsOutputV1',
        'radial': 'RadialRehydrationInstructionsOutputV1',
        'radial_gauge': 'RadialGaugeRehydrationInstructionsOutputV1',
        'series_identifier': 'str'
    }

    attribute_map = {
        'lookup': 'lookup',
        'map_marker': 'mapMarker',
        'radial': 'radial',
        'radial_gauge': 'radialGauge',
        'series_identifier': 'seriesIdentifier'
    }

    def __init__(self, lookup=None, map_marker=None, radial=None, radial_gauge=None, series_identifier=None):
        """
        RehydrationInstructionsOutputV1 - a model defined in Swagger
        """

        self._lookup = None
        self._map_marker = None
        self._radial = None
        self._radial_gauge = None
        self._series_identifier = None

        if lookup is not None:
          self.lookup = lookup
        if map_marker is not None:
          self.map_marker = map_marker
        if radial is not None:
          self.radial = radial
        if radial_gauge is not None:
          self.radial_gauge = radial_gauge
        if series_identifier is not None:
          self.series_identifier = series_identifier

    @property
    def lookup(self):
        """
        Gets the lookup of this RehydrationInstructionsOutputV1.
        Lookup mapping between chart series display names and data series identifiers

        :return: The lookup of this RehydrationInstructionsOutputV1.
        :rtype: list[RehydrationSeriesLookupOutputV1]
        """
        return self._lookup

    @lookup.setter
    def lookup(self, lookup):
        """
        Sets the lookup of this RehydrationInstructionsOutputV1.
        Lookup mapping between chart series display names and data series identifiers

        :param lookup: The lookup of this RehydrationInstructionsOutputV1.
        :type: list[RehydrationSeriesLookupOutputV1]
        """

        self._lookup = lookup

    @property
    def map_marker(self):
        """
        Gets the map_marker of this RehydrationInstructionsOutputV1.

        :return: The map_marker of this RehydrationInstructionsOutputV1.
        :rtype: MapMarkerRehydrationInstructionsOutputV1
        """
        return self._map_marker

    @map_marker.setter
    def map_marker(self, map_marker):
        """
        Sets the map_marker of this RehydrationInstructionsOutputV1.

        :param map_marker: The map_marker of this RehydrationInstructionsOutputV1.
        :type: MapMarkerRehydrationInstructionsOutputV1
        """

        self._map_marker = map_marker

    @property
    def radial(self):
        """
        Gets the radial of this RehydrationInstructionsOutputV1.

        :return: The radial of this RehydrationInstructionsOutputV1.
        :rtype: RadialRehydrationInstructionsOutputV1
        """
        return self._radial

    @radial.setter
    def radial(self, radial):
        """
        Sets the radial of this RehydrationInstructionsOutputV1.

        :param radial: The radial of this RehydrationInstructionsOutputV1.
        :type: RadialRehydrationInstructionsOutputV1
        """

        self._radial = radial

    @property
    def radial_gauge(self):
        """
        Gets the radial_gauge of this RehydrationInstructionsOutputV1.

        :return: The radial_gauge of this RehydrationInstructionsOutputV1.
        :rtype: RadialGaugeRehydrationInstructionsOutputV1
        """
        return self._radial_gauge

    @radial_gauge.setter
    def radial_gauge(self, radial_gauge):
        """
        Sets the radial_gauge of this RehydrationInstructionsOutputV1.

        :param radial_gauge: The radial_gauge of this RehydrationInstructionsOutputV1.
        :type: RadialGaugeRehydrationInstructionsOutputV1
        """

        self._radial_gauge = radial_gauge

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RehydrationInstructionsOutputV1.
        Identifier that maps series data to chart options

        :return: The series_identifier of this RehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RehydrationInstructionsOutputV1.
        Identifier that maps series data to chart options

        :param series_identifier: The series_identifier of this RehydrationInstructionsOutputV1.
        :type: str
        """

        self._series_identifier = series_identifier

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RehydrationInstructionsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
