# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GroupBy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'group_keys': 'list[object]',
        'row_group_column_ids': 'list[str]',
        'value_columns': 'list[GroupValueColumn]'
    }

    attribute_map = {
        'group_keys': 'groupKeys',
        'row_group_column_ids': 'rowGroupColumnIds',
        'value_columns': 'valueColumns'
    }

    def __init__(self, group_keys=None, row_group_column_ids=None, value_columns=None):
        """
        GroupBy - a model defined in Swagger
        """

        self._group_keys = None
        self._row_group_column_ids = None
        self._value_columns = None

        if group_keys is not None:
          self.group_keys = group_keys
        if row_group_column_ids is not None:
          self.row_group_column_ids = row_group_column_ids
        if value_columns is not None:
          self.value_columns = value_columns

    @property
    def group_keys(self):
        """
        Gets the group_keys of this GroupBy.
        Expanded group nodes

        :return: The group_keys of this GroupBy.
        :rtype: list[object]
        """
        return self._group_keys

    @group_keys.setter
    def group_keys(self, group_keys):
        """
        Sets the group_keys of this GroupBy.
        Expanded group nodes

        :param group_keys: The group_keys of this GroupBy.
        :type: list[object]
        """

        self._group_keys = group_keys

    @property
    def row_group_column_ids(self):
        """
        Gets the row_group_column_ids of this GroupBy.
        Columns to group by

        :return: The row_group_column_ids of this GroupBy.
        :rtype: list[str]
        """
        return self._row_group_column_ids

    @row_group_column_ids.setter
    def row_group_column_ids(self, row_group_column_ids):
        """
        Sets the row_group_column_ids of this GroupBy.
        Columns to group by

        :param row_group_column_ids: The row_group_column_ids of this GroupBy.
        :type: list[str]
        """

        self._row_group_column_ids = row_group_column_ids

    @property
    def value_columns(self):
        """
        Gets the value_columns of this GroupBy.
        Columns to aggregate on

        :return: The value_columns of this GroupBy.
        :rtype: list[GroupValueColumn]
        """
        return self._value_columns

    @value_columns.setter
    def value_columns(self, value_columns):
        """
        Sets the value_columns of this GroupBy.
        Columns to aggregate on

        :param value_columns: The value_columns of this GroupBy.
        :type: list[GroupValueColumn]
        """

        self._value_columns = value_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GroupBy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
