# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class Filter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'composite_filter': 'CompositeFilter',
        'simple_filter': 'SimpleFilter',
        'value_filter': 'ValueFilter'
    }

    attribute_map = {
        'composite_filter': 'compositeFilter',
        'simple_filter': 'simpleFilter',
        'value_filter': 'valueFilter'
    }

    def __init__(self, composite_filter=None, simple_filter=None, value_filter=None):
        """
        Filter - a model defined in Swagger
        """

        self._composite_filter = None
        self._simple_filter = None
        self._value_filter = None

        if composite_filter is not None:
          self.composite_filter = composite_filter
        if simple_filter is not None:
          self.simple_filter = simple_filter
        if value_filter is not None:
          self.value_filter = value_filter

    @property
    def composite_filter(self):
        """
        Gets the composite_filter of this Filter.

        :return: The composite_filter of this Filter.
        :rtype: CompositeFilter
        """
        return self._composite_filter

    @composite_filter.setter
    def composite_filter(self, composite_filter):
        """
        Sets the composite_filter of this Filter.

        :param composite_filter: The composite_filter of this Filter.
        :type: CompositeFilter
        """

        self._composite_filter = composite_filter

    @property
    def simple_filter(self):
        """
        Gets the simple_filter of this Filter.

        :return: The simple_filter of this Filter.
        :rtype: SimpleFilter
        """
        return self._simple_filter

    @simple_filter.setter
    def simple_filter(self, simple_filter):
        """
        Sets the simple_filter of this Filter.

        :param simple_filter: The simple_filter of this Filter.
        :type: SimpleFilter
        """

        self._simple_filter = simple_filter

    @property
    def value_filter(self):
        """
        Gets the value_filter of this Filter.

        :return: The value_filter of this Filter.
        :rtype: ValueFilter
        """
        return self._value_filter

    @value_filter.setter
    def value_filter(self, value_filter):
        """
        Sets the value_filter of this Filter.

        :param value_filter: The value_filter of this Filter.
        :type: ValueFilter
        """

        self._value_filter = value_filter

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
