# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TileUpdateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background_color': 'str',
        'border_color': 'str',
        'chart_options': 'str',
        'data_view_id': 'str',
        'decimal_places': 'int',
        'grouped_by_key': 'str',
        'height': 'int',
        'name': 'str',
        'prompt': 'str',
        'rehydration_instructions': 'RehydrationInstructionsInputV1',
        'type': 'str',
        'unit': 'str',
        'value_column': 'str',
        'width': 'int',
        'worksheet_id': 'str',
        'x': 'int',
        'y': 'int'
    }

    attribute_map = {
        'background_color': 'backgroundColor',
        'border_color': 'borderColor',
        'chart_options': 'chartOptions',
        'data_view_id': 'dataViewId',
        'decimal_places': 'decimalPlaces',
        'grouped_by_key': 'groupedByKey',
        'height': 'height',
        'name': 'name',
        'prompt': 'prompt',
        'rehydration_instructions': 'rehydrationInstructions',
        'type': 'type',
        'unit': 'unit',
        'value_column': 'valueColumn',
        'width': 'width',
        'worksheet_id': 'worksheetId',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, background_color=None, border_color=None, chart_options=None, data_view_id=None, decimal_places=None, grouped_by_key=None, height=None, name=None, prompt=None, rehydration_instructions=None, type=None, unit=None, value_column=None, width=None, worksheet_id=None, x=None, y=None):
        """
        TileUpdateInputV1 - a model defined in Swagger
        """

        self._background_color = None
        self._border_color = None
        self._chart_options = None
        self._data_view_id = None
        self._decimal_places = None
        self._grouped_by_key = None
        self._height = None
        self._name = None
        self._prompt = None
        self._rehydration_instructions = None
        self._type = None
        self._unit = None
        self._value_column = None
        self._width = None
        self._worksheet_id = None
        self._x = None
        self._y = None

        if background_color is not None:
          self.background_color = background_color
        if border_color is not None:
          self.border_color = border_color
        if chart_options is not None:
          self.chart_options = chart_options
        if data_view_id is not None:
          self.data_view_id = data_view_id
        if decimal_places is not None:
          self.decimal_places = decimal_places
        if grouped_by_key is not None:
          self.grouped_by_key = grouped_by_key
        if height is not None:
          self.height = height
        if name is not None:
          self.name = name
        if prompt is not None:
          self.prompt = prompt
        if rehydration_instructions is not None:
          self.rehydration_instructions = rehydration_instructions
        if type is not None:
          self.type = type
        if unit is not None:
          self.unit = unit
        if value_column is not None:
          self.value_column = value_column
        if width is not None:
          self.width = width
        if worksheet_id is not None:
          self.worksheet_id = worksheet_id
        if x is not None:
          self.x = x
        if y is not None:
          self.y = y

    @property
    def background_color(self):
        """
        Gets the background_color of this TileUpdateInputV1.
        The background color of the tile (CSS color value)

        :return: The background_color of this TileUpdateInputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this TileUpdateInputV1.
        The background color of the tile (CSS color value)

        :param background_color: The background_color of this TileUpdateInputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def border_color(self):
        """
        Gets the border_color of this TileUpdateInputV1.
        The border color of the tile (CSS color value)

        :return: The border_color of this TileUpdateInputV1.
        :rtype: str
        """
        return self._border_color

    @border_color.setter
    def border_color(self, border_color):
        """
        Sets the border_color of this TileUpdateInputV1.
        The border color of the tile (CSS color value)

        :param border_color: The border_color of this TileUpdateInputV1.
        :type: str
        """

        self._border_color = border_color

    @property
    def chart_options(self):
        """
        Gets the chart_options of this TileUpdateInputV1.
        Chart options as JSON (for chart tiles)

        :return: The chart_options of this TileUpdateInputV1.
        :rtype: str
        """
        return self._chart_options

    @chart_options.setter
    def chart_options(self, chart_options):
        """
        Sets the chart_options of this TileUpdateInputV1.
        Chart options as JSON (for chart tiles)

        :param chart_options: The chart_options of this TileUpdateInputV1.
        :type: str
        """

        self._chart_options = chart_options

    @property
    def data_view_id(self):
        """
        Gets the data_view_id of this TileUpdateInputV1.
        Data view ID (for chart tiles)

        :return: The data_view_id of this TileUpdateInputV1.
        :rtype: str
        """
        return self._data_view_id

    @data_view_id.setter
    def data_view_id(self, data_view_id):
        """
        Sets the data_view_id of this TileUpdateInputV1.
        Data view ID (for chart tiles)

        :param data_view_id: The data_view_id of this TileUpdateInputV1.
        :type: str
        """

        self._data_view_id = data_view_id

    @property
    def decimal_places(self):
        """
        Gets the decimal_places of this TileUpdateInputV1.
        Number of decimal places to display (for KPI tiles)

        :return: The decimal_places of this TileUpdateInputV1.
        :rtype: int
        """
        return self._decimal_places

    @decimal_places.setter
    def decimal_places(self, decimal_places):
        """
        Sets the decimal_places of this TileUpdateInputV1.
        Number of decimal places to display (for KPI tiles)

        :param decimal_places: The decimal_places of this TileUpdateInputV1.
        :type: int
        """

        self._decimal_places = decimal_places

    @property
    def grouped_by_key(self):
        """
        Gets the grouped_by_key of this TileUpdateInputV1.
        Grouped by key (for chart tiles)

        :return: The grouped_by_key of this TileUpdateInputV1.
        :rtype: str
        """
        return self._grouped_by_key

    @grouped_by_key.setter
    def grouped_by_key(self, grouped_by_key):
        """
        Sets the grouped_by_key of this TileUpdateInputV1.
        Grouped by key (for chart tiles)

        :param grouped_by_key: The grouped_by_key of this TileUpdateInputV1.
        :type: str
        """

        self._grouped_by_key = grouped_by_key

    @property
    def height(self):
        """
        Gets the height of this TileUpdateInputV1.
        The height of the tile in grid units

        :return: The height of this TileUpdateInputV1.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this TileUpdateInputV1.
        The height of the tile in grid units

        :param height: The height of this TileUpdateInputV1.
        :type: int
        """

        self._height = height

    @property
    def name(self):
        """
        Gets the name of this TileUpdateInputV1.
        The name of the tile

        :return: The name of this TileUpdateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TileUpdateInputV1.
        The name of the tile

        :param name: The name of this TileUpdateInputV1.
        :type: str
        """

        self._name = name

    @property
    def prompt(self):
        """
        Gets the prompt of this TileUpdateInputV1.
        Prompt used to generate the chart (for chart tiles created via AI)

        :return: The prompt of this TileUpdateInputV1.
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """
        Sets the prompt of this TileUpdateInputV1.
        Prompt used to generate the chart (for chart tiles created via AI)

        :param prompt: The prompt of this TileUpdateInputV1.
        :type: str
        """

        self._prompt = prompt

    @property
    def rehydration_instructions(self):
        """
        Gets the rehydration_instructions of this TileUpdateInputV1.

        :return: The rehydration_instructions of this TileUpdateInputV1.
        :rtype: RehydrationInstructionsInputV1
        """
        return self._rehydration_instructions

    @rehydration_instructions.setter
    def rehydration_instructions(self, rehydration_instructions):
        """
        Sets the rehydration_instructions of this TileUpdateInputV1.

        :param rehydration_instructions: The rehydration_instructions of this TileUpdateInputV1.
        :type: RehydrationInstructionsInputV1
        """

        self._rehydration_instructions = rehydration_instructions

    @property
    def type(self):
        """
        Gets the type of this TileUpdateInputV1.
        The type of tile (Worksheet, Chart, CKEditor, Filter, KPI, Table)

        :return: The type of this TileUpdateInputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TileUpdateInputV1.
        The type of tile (Worksheet, Chart, CKEditor, Filter, KPI, Table)

        :param type: The type of this TileUpdateInputV1.
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """
        Gets the unit of this TileUpdateInputV1.
        The unit to display with the value (for KPI tiles)

        :return: The unit of this TileUpdateInputV1.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this TileUpdateInputV1.
        The unit to display with the value (for KPI tiles)

        :param unit: The unit of this TileUpdateInputV1.
        :type: str
        """

        self._unit = unit

    @property
    def value_column(self):
        """
        Gets the value_column of this TileUpdateInputV1.
        The column name containing the value to display (for KPI tiles)

        :return: The value_column of this TileUpdateInputV1.
        :rtype: str
        """
        return self._value_column

    @value_column.setter
    def value_column(self, value_column):
        """
        Sets the value_column of this TileUpdateInputV1.
        The column name containing the value to display (for KPI tiles)

        :param value_column: The value_column of this TileUpdateInputV1.
        :type: str
        """

        self._value_column = value_column

    @property
    def width(self):
        """
        Gets the width of this TileUpdateInputV1.
        The width of the tile in grid units

        :return: The width of this TileUpdateInputV1.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this TileUpdateInputV1.
        The width of the tile in grid units

        :param width: The width of this TileUpdateInputV1.
        :type: int
        """

        self._width = width

    @property
    def worksheet_id(self):
        """
        Gets the worksheet_id of this TileUpdateInputV1.
        The ID of the worksheet (for worksheet tiles)

        :return: The worksheet_id of this TileUpdateInputV1.
        :rtype: str
        """
        return self._worksheet_id

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id):
        """
        Sets the worksheet_id of this TileUpdateInputV1.
        The ID of the worksheet (for worksheet tiles)

        :param worksheet_id: The worksheet_id of this TileUpdateInputV1.
        :type: str
        """

        self._worksheet_id = worksheet_id

    @property
    def x(self):
        """
        Gets the x of this TileUpdateInputV1.
        The X position of the tile in the grid

        :return: The x of this TileUpdateInputV1.
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this TileUpdateInputV1.
        The X position of the tile in the grid

        :param x: The x of this TileUpdateInputV1.
        :type: int
        """

        self._x = x

    @property
    def y(self):
        """
        Gets the y of this TileUpdateInputV1.
        The Y position of the tile in the grid

        :return: The y of this TileUpdateInputV1.
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this TileUpdateInputV1.
        The Y position of the tile in the grid

        :param y: The y of this TileUpdateInputV1.
        :type: int
        """

        self._y = y

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TileUpdateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
