# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleDescendantSearchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancestor_property': 'str',
        'item_types': 'list[str]',
        'property_match_operators': 'list[str]',
        'property_names': 'list[str]',
        'property_values': 'list[str]'
    }

    attribute_map = {
        'ancestor_property': 'ancestorProperty',
        'item_types': 'itemTypes',
        'property_match_operators': 'propertyMatchOperators',
        'property_names': 'propertyNames',
        'property_values': 'propertyValues'
    }

    def __init__(self, ancestor_property=None, item_types=None, property_match_operators=None, property_names=None, property_values=None):
        """
        ColumnRuleDescendantSearchInputV1 - a model defined in Swagger
        """

        self._ancestor_property = None
        self._item_types = None
        self._property_match_operators = None
        self._property_names = None
        self._property_values = None

        if ancestor_property is not None:
          self.ancestor_property = ancestor_property
        if item_types is not None:
          self.item_types = item_types
        if property_match_operators is not None:
          self.property_match_operators = property_match_operators
        if property_names is not None:
          self.property_names = property_names
        if property_values is not None:
          self.property_values = property_values

    @property
    def ancestor_property(self):
        """
        Gets the ancestor_property of this ColumnRuleDescendantSearchInputV1.
        Accessor of the level in the event to search descendents from: ancestor[<level>] or parent[<level>].  If empty, the search will be performed from the source level of the event

        :return: The ancestor_property of this ColumnRuleDescendantSearchInputV1.
        :rtype: str
        """
        return self._ancestor_property

    @ancestor_property.setter
    def ancestor_property(self, ancestor_property):
        """
        Sets the ancestor_property of this ColumnRuleDescendantSearchInputV1.
        Accessor of the level in the event to search descendents from: ancestor[<level>] or parent[<level>].  If empty, the search will be performed from the source level of the event

        :param ancestor_property: The ancestor_property of this ColumnRuleDescendantSearchInputV1.
        :type: str
        """

        self._ancestor_property = ancestor_property

    @property
    def item_types(self):
        """
        Gets the item_types of this ColumnRuleDescendantSearchInputV1.
        The types of item to search for. If specified, each type must be a valid item type. If not              specified, the rule will search within all Signals, Conditions, and Scalars.

        :return: The item_types of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._item_types

    @item_types.setter
    def item_types(self, item_types):
        """
        Sets the item_types of this ColumnRuleDescendantSearchInputV1.
        The types of item to search for. If specified, each type must be a valid item type. If not              specified, the rule will search within all Signals, Conditions, and Scalars.

        :param item_types: The item_types of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """

        self._item_types = item_types

    @property
    def property_match_operators(self):
        """
        Gets the property_match_operators of this ColumnRuleDescendantSearchInputV1.
        The operators to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN, STRING_CONTAINS, REGEX_MATCHES, and NOT_REGEX_MATCHES.

        :return: The property_match_operators of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_match_operators

    @property_match_operators.setter
    def property_match_operators(self, property_match_operators):
        """
        Sets the property_match_operators of this ColumnRuleDescendantSearchInputV1.
        The operators to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN, STRING_CONTAINS, REGEX_MATCHES, and NOT_REGEX_MATCHES.

        :param property_match_operators: The property_match_operators of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_match_operators is None:
            raise ValueError("Invalid value for `property_match_operators`, must not be `None`")

        self._property_match_operators = property_match_operators

    @property
    def property_names(self):
        """
        Gets the property_names of this ColumnRuleDescendantSearchInputV1.
        The property names to search.

        :return: The property_names of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_names

    @property_names.setter
    def property_names(self, property_names):
        """
        Sets the property_names of this ColumnRuleDescendantSearchInputV1.
        The property names to search.

        :param property_names: The property_names of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_names is None:
            raise ValueError("Invalid value for `property_names`, must not be `None`")

        self._property_names = property_names

    @property
    def property_values(self):
        """
        Gets the property_values of this ColumnRuleDescendantSearchInputV1.
        The property values to search for. 

        :return: The property_values of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_values

    @property_values.setter
    def property_values(self, property_values):
        """
        Sets the property_values of this ColumnRuleDescendantSearchInputV1.
        The property values to search for. 

        :param property_values: The property_values of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_values is None:
            raise ValueError("Invalid value for `property_values`, must not be `None`")

        self._property_values = property_values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleDescendantSearchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
