# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelTableApplicationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_output': 'TableComputeOutputV1',
        'feature_values': 'list[FeatureValueOutputV1]'
    }

    attribute_map = {
        'compute_output': 'computeOutput',
        'feature_values': 'featureValues'
    }

    def __init__(self, compute_output=None, feature_values=None):
        """
        ModelTableApplicationOutputV1 - a model defined in Swagger
        """

        self._compute_output = None
        self._feature_values = None

        if compute_output is not None:
          self.compute_output = compute_output
        if feature_values is not None:
          self.feature_values = feature_values

    @property
    def compute_output(self):
        """
        Gets the compute_output of this ModelTableApplicationOutputV1.

        :return: The compute_output of this ModelTableApplicationOutputV1.
        :rtype: TableComputeOutputV1
        """
        return self._compute_output

    @compute_output.setter
    def compute_output(self, compute_output):
        """
        Sets the compute_output of this ModelTableApplicationOutputV1.

        :param compute_output: The compute_output of this ModelTableApplicationOutputV1.
        :type: TableComputeOutputV1
        """

        self._compute_output = compute_output

    @property
    def feature_values(self):
        """
        Gets the feature_values of this ModelTableApplicationOutputV1.
        List of feature values applied to the table

        :return: The feature_values of this ModelTableApplicationOutputV1.
        :rtype: list[FeatureValueOutputV1]
        """
        return self._feature_values

    @feature_values.setter
    def feature_values(self, feature_values):
        """
        Sets the feature_values of this ModelTableApplicationOutputV1.
        List of feature values applied to the table

        :param feature_values: The feature_values of this ModelTableApplicationOutputV1.
        :type: list[FeatureValueOutputV1]
        """

        self._feature_values = feature_values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelTableApplicationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
