# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelHierarchyOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_name': 'str',
        'children': 'list[LabelHierarchyOutputV1]',
        'label_id': 'str',
        'label_name': 'str'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_name': 'categoryName',
        'children': 'children',
        'label_id': 'labelId',
        'label_name': 'labelName'
    }

    def __init__(self, category_id=None, category_name=None, children=None, label_id=None, label_name=None):
        """
        LabelHierarchyOutputV1 - a model defined in Swagger
        """

        self._category_id = None
        self._category_name = None
        self._children = None
        self._label_id = None
        self._label_name = None

        if category_id is not None:
          self.category_id = category_id
        if category_name is not None:
          self.category_name = category_name
        if children is not None:
          self.children = children
        if label_id is not None:
          self.label_id = label_id
        if label_name is not None:
          self.label_name = label_name

    @property
    def category_id(self):
        """
        Gets the category_id of this LabelHierarchyOutputV1.
        ID of the label category

        :return: The category_id of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """
        Sets the category_id of this LabelHierarchyOutputV1.
        ID of the label category

        :param category_id: The category_id of this LabelHierarchyOutputV1.
        :type: str
        """
        if category_id is None:
            raise ValueError("Invalid value for `category_id`, must not be `None`")

        self._category_id = category_id

    @property
    def category_name(self):
        """
        Gets the category_name of this LabelHierarchyOutputV1.
        Name of the label category

        :return: The category_name of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this LabelHierarchyOutputV1.
        Name of the label category

        :param category_name: The category_name of this LabelHierarchyOutputV1.
        :type: str
        """
        if category_name is None:
            raise ValueError("Invalid value for `category_name`, must not be `None`")

        self._category_name = category_name

    @property
    def children(self):
        """
        Gets the children of this LabelHierarchyOutputV1.
        Children labels in the hierarchy

        :return: The children of this LabelHierarchyOutputV1.
        :rtype: list[LabelHierarchyOutputV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this LabelHierarchyOutputV1.
        Children labels in the hierarchy

        :param children: The children of this LabelHierarchyOutputV1.
        :type: list[LabelHierarchyOutputV1]
        """
        if children is None:
            raise ValueError("Invalid value for `children`, must not be `None`")

        self._children = children

    @property
    def label_id(self):
        """
        Gets the label_id of this LabelHierarchyOutputV1.
        ID of the label

        :return: The label_id of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._label_id

    @label_id.setter
    def label_id(self, label_id):
        """
        Sets the label_id of this LabelHierarchyOutputV1.
        ID of the label

        :param label_id: The label_id of this LabelHierarchyOutputV1.
        :type: str
        """
        if label_id is None:
            raise ValueError("Invalid value for `label_id`, must not be `None`")

        self._label_id = label_id

    @property
    def label_name(self):
        """
        Gets the label_name of this LabelHierarchyOutputV1.
        Name of the label

        :return: The label_name of this LabelHierarchyOutputV1.
        :rtype: str
        """
        return self._label_name

    @label_name.setter
    def label_name(self, label_name):
        """
        Sets the label_name of this LabelHierarchyOutputV1.
        Name of the label

        :param label_name: The label_name of this LabelHierarchyOutputV1.
        :type: str
        """
        if label_name is None:
            raise ValueError("Invalid value for `label_name`, must not be `None`")

        self._label_name = label_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelHierarchyOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
