# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleConcatInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_indexes': 'list[int]',
        'prefix': 'str',
        'separator': 'str',
        'suffix': 'str'
    }

    attribute_map = {
        'column_indexes': 'columnIndexes',
        'prefix': 'prefix',
        'separator': 'separator',
        'suffix': 'suffix'
    }

    def __init__(self, column_indexes=None, prefix=None, separator=None, suffix=None):
        """
        ColumnRuleConcatInputV1 - a model defined in Swagger
        """

        self._column_indexes = None
        self._prefix = None
        self._separator = None
        self._suffix = None

        if column_indexes is not None:
          self.column_indexes = column_indexes
        if prefix is not None:
          self.prefix = prefix
        if separator is not None:
          self.separator = separator
        if suffix is not None:
          self.suffix = suffix

    @property
    def column_indexes(self):
        """
        Gets the column_indexes of this ColumnRuleConcatInputV1.
        The indexes of the columns that references the items to concatenate. A column index is 1-based

        :return: The column_indexes of this ColumnRuleConcatInputV1.
        :rtype: list[int]
        """
        return self._column_indexes

    @column_indexes.setter
    def column_indexes(self, column_indexes):
        """
        Sets the column_indexes of this ColumnRuleConcatInputV1.
        The indexes of the columns that references the items to concatenate. A column index is 1-based

        :param column_indexes: The column_indexes of this ColumnRuleConcatInputV1.
        :type: list[int]
        """
        if column_indexes is None:
            raise ValueError("Invalid value for `column_indexes`, must not be `None`")

        self._column_indexes = column_indexes

    @property
    def prefix(self):
        """
        Gets the prefix of this ColumnRuleConcatInputV1.
        The prefix before the concatenated columns. Defaults to ''

        :return: The prefix of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this ColumnRuleConcatInputV1.
        The prefix before the concatenated columns. Defaults to ''

        :param prefix: The prefix of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._prefix = prefix

    @property
    def separator(self):
        """
        Gets the separator of this ColumnRuleConcatInputV1.
        The separator between columns being concatenated. Defaults to ''

        :return: The separator of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._separator

    @separator.setter
    def separator(self, separator):
        """
        Sets the separator of this ColumnRuleConcatInputV1.
        The separator between columns being concatenated. Defaults to ''

        :param separator: The separator of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._separator = separator

    @property
    def suffix(self):
        """
        Gets the suffix of this ColumnRuleConcatInputV1.
        The suffix after the concatenated columns. Defaults to ''

        :return: The suffix of this ColumnRuleConcatInputV1.
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """
        Sets the suffix of this ColumnRuleConcatInputV1.
        The suffix after the concatenated columns. Defaults to ''

        :param suffix: The suffix of this ColumnRuleConcatInputV1.
        :type: str
        """

        self._suffix = suffix

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleConcatInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
