# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CommentCategoryInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'help_text': 'str',
        'icon': 'str',
        'name': 'str',
        'title': 'str'
    }

    attribute_map = {
        'help_text': 'helpText',
        'icon': 'icon',
        'name': 'name',
        'title': 'title'
    }

    def __init__(self, help_text=None, icon=None, name=None, title=None):
        """
        CommentCategoryInputV1 - a model defined in Swagger
        """

        self._help_text = None
        self._icon = None
        self._name = None
        self._title = None

        if help_text is not None:
          self.help_text = help_text
        if icon is not None:
          self.icon = icon
        if name is not None:
          self.name = name
        if title is not None:
          self.title = title

    @property
    def help_text(self):
        """
        Gets the help_text of this CommentCategoryInputV1.
        Help text for the comment category (displayed as placeholder)

        :return: The help_text of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._help_text

    @help_text.setter
    def help_text(self, help_text):
        """
        Sets the help_text of this CommentCategoryInputV1.
        Help text for the comment category (displayed as placeholder)

        :param help_text: The help_text of this CommentCategoryInputV1.
        :type: str
        """

        self._help_text = help_text

    @property
    def icon(self):
        """
        Gets the icon of this CommentCategoryInputV1.
        Icon of the comment category

        :return: The icon of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this CommentCategoryInputV1.
        Icon of the comment category

        :param icon: The icon of this CommentCategoryInputV1.
        :type: str
        """

        self._icon = icon

    @property
    def name(self):
        """
        Gets the name of this CommentCategoryInputV1.
        Name of the comment category

        :return: The name of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CommentCategoryInputV1.
        Name of the comment category

        :param name: The name of this CommentCategoryInputV1.
        :type: str
        """

        self._name = name

    @property
    def title(self):
        """
        Gets the title of this CommentCategoryInputV1.
        Title of the comment category (displayed as column header)

        :return: The title of this CommentCategoryInputV1.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CommentCategoryInputV1.
        Title of the comment category (displayed as column header)

        :param title: The title of this CommentCategoryInputV1.
        :type: str
        """

        self._title = title

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CommentCategoryInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
