# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CapsuleEventInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_id': 'str',
        'end': 'object',
        'id': 'str',
        'properties': 'list[TablePropertyInputV1]',
        'start': 'object'
    }

    attribute_map = {
        'condition_id': 'conditionId',
        'end': 'end',
        'id': 'id',
        'properties': 'properties',
        'start': 'start'
    }

    def __init__(self, condition_id=None, end=None, id=None, properties=None, start=None):
        """
        CapsuleEventInputV1 - a model defined in Swagger
        """

        self._condition_id = None
        self._end = None
        self._id = None
        self._properties = None
        self._start = None

        if condition_id is not None:
          self.condition_id = condition_id
        if end is not None:
          self.end = end
        if id is not None:
          self.id = id
        if properties is not None:
          self.properties = properties
        if start is not None:
          self.start = start

    @property
    def condition_id(self):
        """
        Gets the condition_id of this CapsuleEventInputV1.
        The ID of the condition that this capsule belongs to

        :return: The condition_id of this CapsuleEventInputV1.
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """
        Sets the condition_id of this CapsuleEventInputV1.
        The ID of the condition that this capsule belongs to

        :param condition_id: The condition_id of this CapsuleEventInputV1.
        :type: str
        """
        if condition_id is None:
            raise ValueError("Invalid value for `condition_id`, must not be `None`")

        self._condition_id = condition_id

    @property
    def end(self):
        """
        Gets the end of this CapsuleEventInputV1.
        The end of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :return: The end of this CapsuleEventInputV1.
        :rtype: object
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this CapsuleEventInputV1.
        The end of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :param end: The end of this CapsuleEventInputV1.
        :type: object
        """
        if end is None:
            raise ValueError("Invalid value for `end`, must not be `None`")

        self._end = end

    @property
    def id(self):
        """
        Gets the id of this CapsuleEventInputV1.
        The unique ID of the capsule

        :return: The id of this CapsuleEventInputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CapsuleEventInputV1.
        The unique ID of the capsule

        :param id: The id of this CapsuleEventInputV1.
        :type: str
        """

        self._id = id

    @property
    def properties(self):
        """
        Gets the properties of this CapsuleEventInputV1.
        A list of properties representing the capsule properties

        :return: The properties of this CapsuleEventInputV1.
        :rtype: list[TablePropertyInputV1]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CapsuleEventInputV1.
        A list of properties representing the capsule properties

        :param properties: The properties of this CapsuleEventInputV1.
        :type: list[TablePropertyInputV1]
        """

        self._properties = properties

    @property
    def start(self):
        """
        Gets the start of this CapsuleEventInputV1.
        The start of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :return: The start of this CapsuleEventInputV1.
        :rtype: object
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this CapsuleEventInputV1.
        The start of the capsule, either in nanoseconds or an ISO-8601 timestamp

        :param start: The start of this CapsuleEventInputV1.
        :type: object
        """
        if start is None:
            raise ValueError("Invalid value for `start`, must not be `None`")

        self._start = start

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CapsuleEventInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
