# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class MaterializedTableSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_column_properties': 'list[PropertiesForItemUUIDColumnInputV1]',
        'condition_and_metric_column': 'str',
        'condition_stats': 'list[ConditionTableStatInputForTableV1]',
        'table_id': 'str'
    }

    attribute_map = {
        'additional_column_properties': 'additionalColumnProperties',
        'condition_and_metric_column': 'conditionAndMetricColumn',
        'condition_stats': 'conditionStats',
        'table_id': 'tableId'
    }

    def __init__(self, additional_column_properties=None, condition_and_metric_column=None, condition_stats=None, table_id=None):
        """
        MaterializedTableSourceV1 - a model defined in Swagger
        """

        self._additional_column_properties = None
        self._condition_and_metric_column = None
        self._condition_stats = None
        self._table_id = None

        if additional_column_properties is not None:
          self.additional_column_properties = additional_column_properties
        if condition_and_metric_column is not None:
          self.condition_and_metric_column = condition_and_metric_column
        if condition_stats is not None:
          self.condition_stats = condition_stats
        if table_id is not None:
          self.table_id = table_id

    @property
    def additional_column_properties(self):
        """
        Gets the additional_column_properties of this MaterializedTableSourceV1.
        Additional column properties to fetch per row that will be concatenated onto each resulting capsule row

        :return: The additional_column_properties of this MaterializedTableSourceV1.
        :rtype: list[PropertiesForItemUUIDColumnInputV1]
        """
        return self._additional_column_properties

    @additional_column_properties.setter
    def additional_column_properties(self, additional_column_properties):
        """
        Sets the additional_column_properties of this MaterializedTableSourceV1.
        Additional column properties to fetch per row that will be concatenated onto each resulting capsule row

        :param additional_column_properties: The additional_column_properties of this MaterializedTableSourceV1.
        :type: list[PropertiesForItemUUIDColumnInputV1]
        """

        self._additional_column_properties = additional_column_properties

    @property
    def condition_and_metric_column(self):
        """
        Gets the condition_and_metric_column of this MaterializedTableSourceV1.
        The condition/condition metric column to run the table across

        :return: The condition_and_metric_column of this MaterializedTableSourceV1.
        :rtype: str
        """
        return self._condition_and_metric_column

    @condition_and_metric_column.setter
    def condition_and_metric_column(self, condition_and_metric_column):
        """
        Sets the condition_and_metric_column of this MaterializedTableSourceV1.
        The condition/condition metric column to run the table across

        :param condition_and_metric_column: The condition_and_metric_column of this MaterializedTableSourceV1.
        :type: str
        """
        if condition_and_metric_column is None:
            raise ValueError("Invalid value for `condition_and_metric_column`, must not be `None`")

        self._condition_and_metric_column = condition_and_metric_column

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this MaterializedTableSourceV1.
        The list of statistics to calculate for the condition columns

        :return: The condition_stats of this MaterializedTableSourceV1.
        :rtype: list[ConditionTableStatInputForTableV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this MaterializedTableSourceV1.
        The list of statistics to calculate for the condition columns

        :param condition_stats: The condition_stats of this MaterializedTableSourceV1.
        :type: list[ConditionTableStatInputForTableV1]
        """

        self._condition_stats = condition_stats

    @property
    def table_id(self):
        """
        Gets the table_id of this MaterializedTableSourceV1.
        ID of the table to generate the condition table from

        :return: The table_id of this MaterializedTableSourceV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this MaterializedTableSourceV1.
        ID of the table to generate the condition table from

        :param table_id: The table_id of this MaterializedTableSourceV1.
        :type: str
        """
        if table_id is None:
            raise ValueError("Invalid value for `table_id`, must not be `None`")

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MaterializedTableSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
