# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filter': 'str',
        'archived': 'bool',
        'background_color': 'str',
        'columns': 'int',
        'created_at': 'str',
        'description': 'str',
        'enabled': 'bool',
        'end_date': 'str',
        'filters': 'list[BoardFilterOutputV1]',
        'id': 'str',
        'locked': 'bool',
        'name': 'str',
        'row_height': 'int',
        'scoped_to': 'str',
        'start_date': 'str',
        'tiles': 'list[TileOutputV1]',
        'updated_at': 'str'
    }

    attribute_map = {
        'applied_filter': 'appliedFilter',
        'archived': 'archived',
        'background_color': 'backgroundColor',
        'columns': 'columns',
        'created_at': 'createdAt',
        'description': 'description',
        'enabled': 'enabled',
        'end_date': 'endDate',
        'filters': 'filters',
        'id': 'id',
        'locked': 'locked',
        'name': 'name',
        'row_height': 'rowHeight',
        'scoped_to': 'scopedTo',
        'start_date': 'startDate',
        'tiles': 'tiles',
        'updated_at': 'updatedAt'
    }

    def __init__(self, applied_filter=None, archived=None, background_color=None, columns=None, created_at=None, description=None, enabled=None, end_date=None, filters=None, id=None, locked=None, name=None, row_height=None, scoped_to=None, start_date=None, tiles=None, updated_at=None):
        """
        BoardOutputV1 - a model defined in Swagger
        """

        self._applied_filter = None
        self._archived = None
        self._background_color = None
        self._columns = None
        self._created_at = None
        self._description = None
        self._enabled = None
        self._end_date = None
        self._filters = None
        self._id = None
        self._locked = None
        self._name = None
        self._row_height = None
        self._scoped_to = None
        self._start_date = None
        self._tiles = None
        self._updated_at = None

        if applied_filter is not None:
          self.applied_filter = applied_filter
        if archived is not None:
          self.archived = archived
        if background_color is not None:
          self.background_color = background_color
        if columns is not None:
          self.columns = columns
        if created_at is not None:
          self.created_at = created_at
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if end_date is not None:
          self.end_date = end_date
        if filters is not None:
          self.filters = filters
        if id is not None:
          self.id = id
        if locked is not None:
          self.locked = locked
        if name is not None:
          self.name = name
        if row_height is not None:
          self.row_height = row_height
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if start_date is not None:
          self.start_date = start_date
        if tiles is not None:
          self.tiles = tiles
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def applied_filter(self):
        """
        Gets the applied_filter of this BoardOutputV1.
        The applied filter configuration

        :return: The applied_filter of this BoardOutputV1.
        :rtype: str
        """
        return self._applied_filter

    @applied_filter.setter
    def applied_filter(self, applied_filter):
        """
        Sets the applied_filter of this BoardOutputV1.
        The applied filter configuration

        :param applied_filter: The applied_filter of this BoardOutputV1.
        :type: str
        """

        self._applied_filter = applied_filter

    @property
    def archived(self):
        """
        Gets the archived of this BoardOutputV1.
        Whether the board is archived

        :return: The archived of this BoardOutputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this BoardOutputV1.
        Whether the board is archived

        :param archived: The archived of this BoardOutputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def background_color(self):
        """
        Gets the background_color of this BoardOutputV1.
        The background color of the board

        :return: The background_color of this BoardOutputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this BoardOutputV1.
        The background color of the board

        :param background_color: The background_color of this BoardOutputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def columns(self):
        """
        Gets the columns of this BoardOutputV1.
        The number of columns in the board grid

        :return: The columns of this BoardOutputV1.
        :rtype: int
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this BoardOutputV1.
        The number of columns in the board grid

        :param columns: The columns of this BoardOutputV1.
        :type: int
        """
        if columns is None:
            raise ValueError("Invalid value for `columns`, must not be `None`")

        self._columns = columns

    @property
    def created_at(self):
        """
        Gets the created_at of this BoardOutputV1.
        The time the board was created

        :return: The created_at of this BoardOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this BoardOutputV1.
        The time the board was created

        :param created_at: The created_at of this BoardOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def description(self):
        """
        Gets the description of this BoardOutputV1.
        The description of the board

        :return: The description of this BoardOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BoardOutputV1.
        The description of the board

        :param description: The description of this BoardOutputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this BoardOutputV1.
        Whether the board is enabled

        :return: The enabled of this BoardOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this BoardOutputV1.
        Whether the board is enabled

        :param enabled: The enabled of this BoardOutputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def end_date(self):
        """
        Gets the end_date of this BoardOutputV1.
        The end date for the date range of the data

        :return: The end_date of this BoardOutputV1.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BoardOutputV1.
        The end date for the date range of the data

        :param end_date: The end_date of this BoardOutputV1.
        :type: str
        """

        self._end_date = end_date

    @property
    def filters(self):
        """
        Gets the filters of this BoardOutputV1.
        Filters configured on this board

        :return: The filters of this BoardOutputV1.
        :rtype: list[BoardFilterOutputV1]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this BoardOutputV1.
        Filters configured on this board

        :param filters: The filters of this BoardOutputV1.
        :type: list[BoardFilterOutputV1]
        """
        if filters is None:
            raise ValueError("Invalid value for `filters`, must not be `None`")

        self._filters = filters

    @property
    def id(self):
        """
        Gets the id of this BoardOutputV1.
        The unique identifier of the board

        :return: The id of this BoardOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BoardOutputV1.
        The unique identifier of the board

        :param id: The id of this BoardOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def locked(self):
        """
        Gets the locked of this BoardOutputV1.
        Whether the board is locked

        :return: The locked of this BoardOutputV1.
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """
        Sets the locked of this BoardOutputV1.
        Whether the board is locked

        :param locked: The locked of this BoardOutputV1.
        :type: bool
        """

        self._locked = locked

    @property
    def name(self):
        """
        Gets the name of this BoardOutputV1.
        The name of the board

        :return: The name of this BoardOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BoardOutputV1.
        The name of the board

        :param name: The name of this BoardOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def row_height(self):
        """
        Gets the row_height of this BoardOutputV1.
        The height of each row in grid units

        :return: The row_height of this BoardOutputV1.
        :rtype: int
        """
        return self._row_height

    @row_height.setter
    def row_height(self, row_height):
        """
        Sets the row_height of this BoardOutputV1.
        The height of each row in grid units

        :param row_height: The row_height of this BoardOutputV1.
        :type: int
        """
        if row_height is None:
            raise ValueError("Invalid value for `row_height`, must not be `None`")

        self._row_height = row_height

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this BoardOutputV1.
        The ID of the workbook this board is scoped to

        :return: The scoped_to of this BoardOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this BoardOutputV1.
        The ID of the workbook this board is scoped to

        :param scoped_to: The scoped_to of this BoardOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def start_date(self):
        """
        Gets the start_date of this BoardOutputV1.
        The start date for the date range of the data

        :return: The start_date of this BoardOutputV1.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BoardOutputV1.
        The start date for the date range of the data

        :param start_date: The start_date of this BoardOutputV1.
        :type: str
        """

        self._start_date = start_date

    @property
    def tiles(self):
        """
        Gets the tiles of this BoardOutputV1.
        The tiles on this board

        :return: The tiles of this BoardOutputV1.
        :rtype: list[TileOutputV1]
        """
        return self._tiles

    @tiles.setter
    def tiles(self, tiles):
        """
        Sets the tiles of this BoardOutputV1.
        The tiles on this board

        :param tiles: The tiles of this BoardOutputV1.
        :type: list[TileOutputV1]
        """
        if tiles is None:
            raise ValueError("Invalid value for `tiles`, must not be `None`")

        self._tiles = tiles

    @property
    def updated_at(self):
        """
        Gets the updated_at of this BoardOutputV1.
        The last time this board was updated

        :return: The updated_at of this BoardOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this BoardOutputV1.
        The last time this board was updated

        :param updated_at: The updated_at of this BoardOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
