# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class VersionSourceItemOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_item_id': 'str',
        'source_item_name': 'str',
        'source_item_type': 'str'
    }

    attribute_map = {
        'source_item_id': 'sourceItemId',
        'source_item_name': 'sourceItemName',
        'source_item_type': 'sourceItemType'
    }

    def __init__(self, source_item_id=None, source_item_name=None, source_item_type=None):
        """
        VersionSourceItemOutputV1 - a model defined in Swagger
        """

        self._source_item_id = None
        self._source_item_name = None
        self._source_item_type = None

        if source_item_id is not None:
          self.source_item_id = source_item_id
        if source_item_name is not None:
          self.source_item_name = source_item_name
        if source_item_type is not None:
          self.source_item_type = source_item_type

    @property
    def source_item_id(self):
        """
        Gets the source_item_id of this VersionSourceItemOutputV1.
        The source item ID for this version

        :return: The source_item_id of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_id

    @source_item_id.setter
    def source_item_id(self, source_item_id):
        """
        Sets the source_item_id of this VersionSourceItemOutputV1.
        The source item ID for this version

        :param source_item_id: The source_item_id of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_id is None:
            raise ValueError("Invalid value for `source_item_id`, must not be `None`")

        self._source_item_id = source_item_id

    @property
    def source_item_name(self):
        """
        Gets the source_item_name of this VersionSourceItemOutputV1.
        The source item name for this version

        :return: The source_item_name of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_name

    @source_item_name.setter
    def source_item_name(self, source_item_name):
        """
        Sets the source_item_name of this VersionSourceItemOutputV1.
        The source item name for this version

        :param source_item_name: The source_item_name of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_name is None:
            raise ValueError("Invalid value for `source_item_name`, must not be `None`")

        self._source_item_name = source_item_name

    @property
    def source_item_type(self):
        """
        Gets the source_item_type of this VersionSourceItemOutputV1.
        The source item type for this version

        :return: The source_item_type of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_type

    @source_item_type.setter
    def source_item_type(self, source_item_type):
        """
        Sets the source_item_type of this VersionSourceItemOutputV1.
        The source item type for this version

        :param source_item_type: The source_item_type of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_type is None:
            raise ValueError("Invalid value for `source_item_type`, must not be `None`")

        self._source_item_type = source_item_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VersionSourceItemOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
